package org.nakedobjects.nos.store.hibernate;

import java.util.Enumeration;

import org.nakedobjects.noa.adapter.NakedCollection;
import org.nakedobjects.noa.adapter.NakedObject;
import org.nakedobjects.noa.adapter.Oid;
import org.nakedobjects.noa.adapter.Persistable;
import org.nakedobjects.noa.adapter.ResolveState;
import org.nakedobjects.noa.adapter.Version;
import org.nakedobjects.noa.spec.NakedObjectSpecification;
import org.nakedobjects.nof.core.util.ToString;


/**
 * Special adapter that allows the HOS to create new adapter for the renewed collection, while allowing the
 * object loader to hold on to a single adapter throughout the life of the parent object. This object is the
 * constant adapter, with the referenced adapter is the adapter for the current collection instance, as
 * created by Hibernate.
 */
public class HibernateCollectionAdapter implements NakedCollection {
    private NakedCollection wrappedCollection;

    public void setCollection(NakedCollection collection) {
        this.wrappedCollection = collection;
    }

    public boolean contains(NakedObject object) {
        return wrappedCollection.contains(object);
    }

    public Enumeration elements() {
        return wrappedCollection.elements();
    }

    public NakedObject firstElement() {
        return wrappedCollection.firstElement();
    }
    
    public NakedObjectSpecification getElementSpecification() {
        return wrappedCollection.getElementSpecification();
    }

    public void init(Object[] elements) {
        wrappedCollection.init(elements);
    }
    
    public int size() {
        return wrappedCollection.size();
    }

    public void changeState(ResolveState newState) {
        wrappedCollection.changeState(newState);
    }

    public void checkLock(Version version) {
        wrappedCollection.checkLock(version);
    }

    public Oid getOid() {
        return wrappedCollection.getOid();
    }

    public ResolveState getResolveState() {
        return wrappedCollection.getResolveState();
    }

    public Version getVersion() {
        return wrappedCollection.getVersion();
    }

    public Persistable persistable() {
        return wrappedCollection.persistable();
    }

    public void setOptimisticLock(Version version) {
        wrappedCollection.setOptimisticLock(version);
    }

    public String getIconName() {
        return wrappedCollection.getIconName();
    }

    public Object getObject() {
        return wrappedCollection.getObject();
    }

    public NakedObjectSpecification getSpecification() {
        return wrappedCollection.getSpecification();
    }

    public String titleString() {
        return wrappedCollection.titleString();
    }

    public String toString() {
        ToString str = new ToString(this);
        str.append("delegate", str);
        return str.toString();
    }

}

// Copyright (c) Naked Objects Group Ltd.
