package org.nakedobjects.nos.store.hibernate.service;

import java.util.List;

import org.hibernate.Session;
import org.nakedobjects.noa.adapter.NakedObject;
import org.nakedobjects.noa.persist.InstancesCriteria;
import org.nakedobjects.noa.spec.NakedObjectSpecification;
import org.nakedobjects.nof.core.context.NakedObjectsContext;


/**
 * Superclass of all InstancesCriteria which use Hibernate to access the database.
 */
public abstract class HibernateInstancesCriteria implements InstancesCriteria {
    public static final int LIST = 0;
    public static final int UNIQUE_RESULT = 1;

    private final Class cls;
    private final int resultType;

    public HibernateInstancesCriteria(final Class cls, final int resultType) {
        this.resultType = resultType;
        this.cls = cls;
    }

    /**
     * provided for serialization purposes only.
     */
    protected HibernateInstancesCriteria() {
        cls = null;
        resultType = LIST;
    }

    public NakedObjectSpecification getSpecification() {
        return NakedObjectsContext.getReflector().loadSpecification(cls);
    }

    /**
     * Not required as this will be in the Hibernate query/criteria
     */
    public boolean includeSubclasses() {
        return false;
    }

    /**
     * Not required as this will be decided by the Hibernate query/criteria
     */
    public boolean matches(final NakedObject object) {
        return false;
    }

    /**
     * Return the results of executing the Hibernate query.
     * 
     * @return a List of persistent Objects
     */
    public abstract List getResults();

    public abstract void setSession(final Session session);

    public int getResultType() {
        return resultType;
    }

    protected Class getCls() {
        return cls;
    }

}
// Copyright (c) Naked Objects Group Ltd.
